import unittest
from ybc_funny import *


class MyTestCase(unittest.TestCase):
    def test_jizhuanwan(self):
        self.assertIsNotNone(jizhuanwan_content())

    def test_raokouling(self):
        self.assertIsNotNone(raokouling())

    def test_xiehouyu(self):
        self.assertIsNotNone(xiehouyu_content())

    def test_miyu(self):
        self.assertIsNotNone(miyu_content())

    def test_xiaohua(self):
        self.assertIsNotNone(xiaohua())


if __name__ == '__main__':
    unittest.main()



import random
from ybc_exception import *
import sys


def xiaohua():
    """
    笑话
    :return: random 笑话
    """
    try:
        data = {
            0: {
                'content': '我的写作水平终于获得了语文老师的认可。三年前，他对我的评语是：无病呻吟。三年后，我又把新写的作品拿给他，看完后他关切地对我说：你有病吧。'
            },
            1: {
                'content': '街头遇到一个乞丐，竟是大学同学，他一开始有点尴尬，但当他发现自己碗里的钱比我碗里的多时，他又显得优越起来。'
            },
            2: {
                'content': '“为什么你社交活动结束后回到家里会有深深的失落感？”——没吃饱！ '
            },
            3: {
                'content': '老师被同学们气得直跺脚，作为班干部我当然不能对这种状况坐视不理，于是迅速冲上讲台在他脚下放了几个山核桃。。。'
            },
            4: {
                'content': '我妈说我是充话费送的，所以我才会天天抱着手机玩，因为里面有电话卡。那是家人的味道。'
            },
            5: {
                'content': '美国人对德国人说：我们听说你们要买华为的5G设备，不要买，他们会监控你们。德国人：你们怎么知道我们要买？美国人：我们从默克尔的电话里听到的。'
            },
            6: {
                'content': '老师真的很奇怪，一边教育我们“做好事不留名”，另一边又经常问“这是谁干的好事？”。'
            },
            7: {
                'content': '如果你上秤是100斤，那么在镜子里看自己大概是90斤，在朋友圈自拍里是85斤。在证件照集体照里105斤，朋友抓拍110斤，视频录像120斤。。。外婆眼里是70斤。'
            },
            8: {
                'content': '如果你对人说，天上有一个看不见的人创造了宇宙，大部分的人会相信你；但如果你对他们说油漆还没干，大部分的人都想上手摸摸、验证一下'
            },
            9: {
                'content': '昨晚预约了快递上门取件还预点了早餐，结果早上睡太死外卖打电话没听见，直接给我放门口窗台了，后来快递员来取件把我外卖寄走了。'
            },
            10: {
                'content': '今天去理发，洗剪吹68，烫发和染发668。我就做了个洗剪吹，结账的时候发现居然收我668。我不服，1米95的经理走出来对我耐心地解释：你看哈，刚才洗头的时候，是不是感觉水很烫？？？'
            },
            11: {
                'content': '老师提醒你：寒假千万条，作业第一条。过节不学习，开学两行泪！'
            },
            12: {
                'content': '你不是真的胖，只是女娲捏土造你的时候土用多了。'
            },
            13: {
                'content': '买了个灯泡，问老板为什么不亮？老板说：这是限亮版。'
            },
            14: {
                'content': '9点半是一个非常适合起床的时间，谈不上赖床，也不算早起。洗漱完毕，吃个简单早饭，也才十点。此时距离中午还剩两个小时，可以做一些重要的事，比如睡个回笼觉。'
            },
            15: {
                'content': '小学二年级我班上一同学的作文：这个周末我去了乡下外婆家，满山都是成熟了的马铃薯，挂在枝头随风摇动。'
            },
            16: {
                'content': '小偷的儿子闷闷不乐，妈妈发现了，问他：“怎么了儿子？”小偷儿子回答：“妈妈，能不能让我爸爸改行，别做小偷了”小偷的媳妇哈哈大笑：“怎么了儿子，是不是觉得爸爸当小偷，你感到很丢人？”小偷的儿子：“丢人倒没什么，你看他昨天给我偷的什么，竟然给我偷了一摞假期作业。”'
            },
            17: {
                'content': '刚上初一的时候，学校对头发要求严格，规定不能超过眉毛，结果第二天检查的时候，我发现同桌居然眉毛剃掉了！'
            },
            18: {
                'content': '小逗号八点钟才起床，脸也顾不得洗，背着书包就往跑。他上气不接下气地跑进教室，喊了声“报告”，就坐在自己座位上，听地理老师讲课。“小逗号，你站起来回答我的问题”，老师用教鞭指着地图，“什么叫赤道？”小逗号红着脸答道：“八点钟上课，八点过了才进教室，就叫迟到！”'
            },
            19: {
                'content': '经济学教授在上课时说道：“同学们，外劳对我们的影响很大，你们谁能知道一国的外劳赚走最多钱？是泰劳、越劳、菲劳，还是……”小逗号抢先回答：“麦当劳！”'
            },
            20: {
                'content': '老师问一名学生：“你的试卷是抄了别人的吧？”小逗号说：“是的。是抄了些，但不全是”。老师：“哪些地方不是抄的呢？”小逗号：“名字不是。”'
            },
            21: {
                'content': '有一个小学老师有很浓重的地方口音，一天上课，他对学生提问：“50+9=？”小逗号心里直嘀咕：“武术+酒=？武术+酒=？”突然恍然大悟，答曰：“醉拳~”'
            },
            22: {
                'content': '在看日本动画片《聪明的一休》的时侯，爸爸问10岁的儿子：“你说一休为什么聪明呢?” “因为他没有头发呀！” “头发与智慧有什么关系呢?” “你不是说妈妈头发长见识短嘛！”'
            },
            23: {
                'content': '子：“如果我考全班第一名，你会怎样?” 父：“那我真要高兴死了！” 子：“爸爸，不要担心，我不会让你死的！”'
            },
            24: {
                'content': '爸爸带着小儿子气喘吁吁地爬到山顶。爸爸说：“快看哪，我们脚下的一片平原景色多好！” “既然下面的景色好，我们干吗要花3个小时爬到上面来呢?爸爸。”'
            },
            25: {
                'content': '小明明天就要考试，但晚上却还在看电视。小明妈妈就担心地问：“书都看完了吗？明天要考试啊！”小明就爽快地回答：“妈，我看完了。”小明妈妈就很开心的赞扬小明：“乖，那明天你一定考得很好呢！”小明哭着说：“妈，我是说，“妈，我看，完了”。”'
            },
            26: {
                'content': '有一个小女孩迷了路，就去找警察叔叔。警察叔叔问明情况后，问小女孩：“你爸爸叫什么名字？”小女孩回答说：“叫亲爱的。”警察听后，很无奈地又问：“那你妈妈叫什么名字呢？”小女孩又回答说：“叫宝贝。”'
            },
            27: {
                'content': '老师把试卷发给每个学生，并要求大家给父母看后请父母在上面签字，再交回来。第二天，老师问乔治：“你没有把试卷给父母看吗？”“看过了。”乔治回答。那为什么没有家长签字呢？乔治伸出满是鞭痕的手：“签在这儿。”'
            },
            28: {
                'content': '儿子：“什么时候到冬天啊，我都想打雪仗了。”父亲：“现在是春天，还要过夏天、秋天，才到冬天。”儿子：“喔，还要过两天啊。”'
            },
            29: {
                'content': '弟：“怎样叫进步？”姐：“今天比昨天做的事情多。”弟：“爸爸有进步，昨天他抽烟在衣服上烧了一个洞，今天烧了三个。”'
            },
            30: {
                'content': ' 父亲：“凡是今天能完成的事情，一定不要拖到明天。”儿子：“这太容易了。把饼干盒拿来！”'
            },
            31: {
                'content': '爸爸讲成语“鹬蚌相争”时，说：“蚌把鹬的嘴夹上以后，蚌说，“我今天不松嘴，明天不松嘴。太阳就会把你晒死的！”6岁的孩子听到这里。问爸爸；“蚌说话是不用嘴的吗？”“不用嘴能讲话吗？”“那它讲话时，嘴不就松开了吗？”'
            },
            32: {
                'content': '孩子：“我发现老爸是个超级球迷！”妈妈：“你怎么发现的？”孩子：“通过他在我成绩单上的签字。零蛋下写着：好球！”'
            },
            33: {
                'content': '宝宝：“妈妈，那是什么？”“那是缆车。”“哦，怪不得走得那么慢，原来是懒车。”'
            },
            34: {
                'content': '之前看喜羊羊和灰太狼，是担心喜羊羊被灰太狼吃掉。可能是看多了之后。现在，巴不得灰太狼可以吃掉一个羊。因为灰太狼已经饿了5年了。'
            },
            35: {
                'content': '一天晚上，小明：“我冷。”爸爸：“那去墙角吧。”小明:“为什么？”爸爸:“因为墙角有90度啊！”'
            },
            36: {
                'content': ' 小明问爸爸：“老爸，我们吃的米饭是从哪里来的啊？” 爸爸说：“你去看下水稻就知道了。”小明半信半疑走到了厕所，打开下水道，捂着鼻子问：“爸爸，你确定米饭是从这里出来的？”'
            },
            37: {
                'content': '从球场上走来一位身高二米一的篮球运动员，他热得汗流浃背。路边两个小学生见了，就议论起来。 甲：“你说这位叔叔为什么这么热？” 乙：“因为他个子高。” 甲：“个子高为什么就热呢？” 乙：“个子高离太阳近嘛！”'
            },
            38: {
                'content': '社会课上老师：“如此这般，所以，大家要好好保护大自然”学生：“老师，那你知道，谁来保护我们人类吗？”老师“不知道……”学生：“奥特曼呀！”'
            },
            39: {
                'content': '小明初学军棋，爸爸问：“师长和旅长谁大？”小明毫不迟疑答道：“师长大。”爸爸好奇的问：“为什么师长比旅长大？”小明得意洋洋的说：“因为狮子比驴大呀。所以狮长比驴长大。”'
            },
            40: {
                'content': '有一天小仁在巷口捡到了十块钱，他很高兴的跑去跟邻居小洋说，可是小洋却信誓旦旦的说：“这一定是我昨天不小心掉在巷口的。”小仁说：“确定是你掉的？可是我捡到的是两张五块钱！”小洋说：“那一定掉的时候摔破了！”'
            },
            41: {
                'content': '妈妈：“马丁，你到厨房里去看一下，看看电灯是否关上了！”马丁去了一下回来说：“妈妈，那里黑咕隆咚的，什么也看不见。”'
            },
            42: {
                'content': '老师：“亮亮，每天早晨你几点起床？”亮亮：“这要看爸爸的鸡毛掸子什么时候捅我。”'
            },
            43: {
                'content': '老师：“亮亮，这次考四科，你科科不及格，你不感到难过吗？”亮亮：“我倒没什么，难过的是我爸爸。”'
            },
            44: {
                'content': '老师：“同学们，现在请你们保持绝对安静，静得你们连落一根针在地上都能听得见。”过了一会儿，全静下来了，一个男生尖叫道:“扔针吧！”'
            },
            45: {
                'content': '“妈妈，家长会上老师表扬我没有？”小华问。“没有，听了半天也没有听到你的名字。”妈妈答道。“那老师念完同学的名字后说等等没有？”“说了。”妈妈答。“那不是表扬了我吗？我就在等等里头！”小华说。'
            },
            46: {
                'content': '甲：“总统今天给我打来电话了！”乙：“太难得了，他都对你说什么了？”甲：“他只说了一句话：“对不起，打错了！”'
            },
            47: {
                'content': '作家的最好写作方式是什么？'
            },
            48: {
                'content': '有一个鸡腿走在路上，它走呀走的突然饿了，于是它就把自己吃了。'
            },
            49: {
                'content': '以前有一个人在睡觉，然后一只蚊子过来咬他了。他被叮醒正准备一只手啪下去的时候，蚊子对他说：“求求你别杀我，今天是我的生日！”那个人听说后，小心翼翼把蚊子放在手心，一边拍手一边唱生日快乐歌。'
            },
            50: {
                'content': '恶心的妈妈伤心地哭了，为什么？因为恶心死了'
            },
            51: {
                'content': '今天下雪路很滑，有一个大爷摔倒了没人扶，我摇摇头跑过去扶，没想到我也摔倒了，结果把大爷踹更远了。'
            },
            52: {
                'content': '老师失踪后，我第一时间去警察局报了案。警察对我说：你先冷静一下，你这样一直笑我们没办法做笔录啊。'
            },
            53: {
                'content': '王老汉掉进水缸，机智的小明往里扔石头然后就喝到水了。'
            },
            54: {
                'content': '不许你们任何人在我面前说我朋友的坏话，不然我也会不知不觉的跟着说起来。'
            },
            55: {
                'content': '早上八点我还在睡觉，老妈打开房间门：“太阳晒屁股啦！”。多亏她的提醒，我给屁股抹了点防晒霜。'
            },
            56: {
                'content': '南宋时期有个爱国诗人叫陆游。 那时金兵入侵，面对着山河破碎、民不聊生的社会。 陆游气坏了。 我们就都不能上网了。'
            },
            57: {
                'content': '蚂蚁和大象结婚，没过多久大象就死去了。然后蚂蚁就因为埋葬大象累死了。'
            },
            58: {
                'content': '第一天，小白兔去河边钓鱼，什么也没钓到，回家了。第二天，小白兔又去河边钓鱼，还是什么也没钓到，回家了。第三天，小白兔刚到河边，一条大鱼从河里跳出来，冲着小白兔大叫：你要是再敢用胡箩卜当鱼饵，我就打死你。'
            },
            59: {
                'content': '这个跳水运动员难度系数非常高，他先转体翻滚一周然后前空翻一周半接着后空翻一个月。'
            },
            60: {
                'content': '两个垃圾桶比赛跑步，跑了很久，后来有一只垃圾桶停下来，说：我们是垃圾桶啊，为什么要跑？'
            },
            61: {
                'content': '小明从十八层跳下来，但是没死。因为小明是塑料袋。'
            },
            62: {
                'content': '小明走在路上，忽然感觉脚很酸，低头一看，原来他踩到了一个柠檬。'
            }
        }
        num = random.randint(0, 62)
        res_str = data[num]['content']
        return res_str

    except Exception as e:
        raise InternalError(e, 'ybc_funny')


def raokouling():
    """
    绕口令
    :return: random 脑筋急转弯
    """
    try:
        data = {
            0: {
                'content': '东边一座楼，楼上两人打拳头。拳头打，打拳头。来了一个人，拉了一头牛，将牛拴在楼脚下，看他两人打拳头。拳头打，打拳头。又来了一个人，领了一只猴，将猴放在牛脚下，看他两人打拳头。拳头打，打拳头。又来了一个人，挑了一担油，将油放在猴脚下，看他两人打拳头。拳头打，打拳头。又来了一个人，挑了一担绸，将绸放在油脚下，看他两人打拳头。拳头打，打拳头，两人打垮车边楼。垮子楼，压倒牛，牛一蹲，蹲倒猴，猴一抓，抓倒油，油一泼，泼上绸。绸问油，卖油买绸来赔绸；油问猴，卖猴买油来赔油；猴问牛，卖牛买猴来赔猴；牛问楼，卖楼买牛来赔牛。只问绸扯油来油扯猴，猴扯牛来牛扯楼。'
            },
            1: {
                'content': '峰上风，峰下枫。峰上风吹蜂会飞，峰下枫，峰下枫挡峰上风。'
            },
            2: {
                'content': '隔着窗户撕字纸，撕了字纸吃柿子。'
            },
            3: {
                'content': '嘴说腿，腿说嘴，嘴说腿爱跑腿，腿说嘴爱卖嘴。光动嘴不动腿，光动腿不动嘴，不如不长腿和嘴。'
            },
            4: {
                'content': '姐姐借刀切茄子，去把儿去叶儿斜切丝，切好茄子烧茄子，炒茄子、蒸茄子，还有一碗焖茄子。'
            },
            5: {
                'content': '陆莉和罗丽，同在一个年级里。陆莉学习很努力，学了语文学物理，尊敬老师守纪律，又讲礼貌又懂理。罗丽穿得很美丽，学习只求差不离，说话做事不考虑，屡次违反校规矩。你想学陆莉，还是学罗丽?'
            },
            6: {
                'content': '蜜蜂酿蜂蜜，蜂蜜养蜜蜂。蜜养蜜蜂蜂酿蜜，蜂酿蜂蜜蜜养蜂。'
            },
            7: {
                'content': '石、斯、施、史四老师，天天和我在一起。石老师教我大公无私，斯老师给我精神食粮，施老师叫我遇事三思，史老师送我知识钥匙。我感谢石、斯、施史四老师。'
            },
            8: {
                'content': '盘盘坐，分果果。果果青，分花生。花生香，分白糖。白糖粘，分盐蛋。盐蛋咸，吃不完。'
            },
            9: {
                'content': '牛斗，斗斗牛。斗牛不斗不斗牛。不是人斗牛，是斗牛斗斗牛。'
            },
            10: {
                'content': '小猴小猴拍皮球，一拍拍到水里头，小猴急得直挠头，小鸭游来托起球。'
            },
            11: {
                'content': '三只牛儿上山岗，山岗上三个牛铃响。牛铃响，响山岗，山岗上三个铃铛响叮当，铃铛响山岗。'
            },
            12: {
                'content': '早招租，晚招租，总找邹周郑曾朱。'
            },
            13: {
                'content': '老婆婆，蒸馍馍，白馍馍，一笸萝。你一个，我一个，甜丝丝，软和和，大伙吃得乐呵呵。'
            },
            14: {
                'content': '隔墙听见人分银，不知道多少人分多少银。只听见人说，人人分半斤银余银四两，人人分四两银余银半斤。'
            },
            15: {
                'content': '墙壁贴壁纸，下雨墙壁湿。壁湿壁纸湿。纸湿壁更湿。撕纸换湿纸，湿纸撕下换壁纸，壁纸不湿纸不撕。'
            },
            16: {
                'content': '补壁拆壁，拆壁补壁。拆壁洞，补壁缝，补在壁缝壁无缝'
            },
            17: {
                'content': '白石园里有座白石塔，白石塔旁开朵白莲花，白莲花映着白石塔，白石塔衬着白莲花。白石塔，白莲花，人人都说美极啦！'
            },
            18: {
                'content': '庙里一只猫，庙外一只猫。庙里猫咬庙外猫，庙外猫咬庙里猫。勿晓得到底是庙里猫咬庙外猫，还是庙外猫咬庙里猫。'
            },
            19: {
                'content': '哥挎瓜筐过宽沟，赶快过沟看怪狗，光看怪狗瓜筐扣，瓜滚筐空哥怪狗。'
            },
            20: {
                'content': '绵绵穿个单坎肩，元元穿个棉坎肩，元元的棉坎肩比绵绵的单坎肩暖，绵绵的单坎肩比元元的棉坎肩好看。'
            },
            21: {
                'content': '家后有座庙天天猫来尿不知是庙尿猫还是猫尿庙'
            },
            22: {
                'content': '出南门，走六步，见着六叔和六舅，叫声六叔和六舅，借我六斗六升好绿豆；过了秋，打了豆，还我六叔六舅六十六斗六升好绿豆。'
            },
            23: {
                'content': '龙和虫，虫和龙。把虫当龙虫是龙，把龙当虫龙是虫。虫在海里虫是龙，龙在沟里龙是虫。'
            },
            24: {
                'content': '东门董家栽了冬瓜，西门胥家栽了西瓜。这人道说：东门董家的冬瓜大过西门胥家的西瓜，那人道说：西门胥家的西瓜大过东门董家的冬瓜。'
            },
            25: {
                'content': '胖胖端了一碗汤，喝汤不等汤晾凉。汤烫烫胖胖，汤烫胖胖烫，要喝汤，汤晾凉了别着忙。'
            },
            26: {
                'content': '卜家卜小五，种了五亩谷。跑来一群鼠，在地里吃谷。小五忙割谷，顾不得捉鼠。小五想捉鼠，就顾不得割谷。忙坏了卜小五，没捉住老鼠，还糟蹋了很多谷。'
            },
            27: {
                'content': '东有嘀嘟寺，山有嘀嘟寺，有个嘀嘟爷，上山去祈福。手提嘀嘟油，腰里别葫芦，嘴念嘀嘟经，三步一叩首。面见嘀嘟佛，佛爷开慈目，大经念三遭，小经唱六度。嘀嘀嘟嘟，嘀嘟嘀嘟，嘀嘀嘟嘟，嘀嘟嘀嘟。嘀嘟梦醒嘀嘟屋，睁眼不见嘀嘟寺，嘀嘟母鸡叫咕咕，嘀嘟老猪打呼噜。'
            },
            28: {
                'content': '玲珑塔，玲珑塔，玲珑宝塔十叁层，塔前有座庙，庙内有老僧，老僧当方丈，徒弟有六人；一个叫青头楞，一个叫楞头青；一个叫僧僧头，一个叫点点头；一个是奔胡卢把，一个是把胡卢奔；青头楞会打磬，楞头青会捧笙；僧僧点会吹管，点点僧会撞钟；奔胡卢把会说话，把胡卢奔会念经。'
            },
            29: {
                'content': '出前门，面冲南，有个面铺面冲南。面铺外，挂着一个蓝布棉门帘。给它摘了那个蓝布棉门帘，面铺还是面冲南；给它挂上那个蓝布棉门帘，面铺还是面冲南。'
            },
            30: {
                'content': '扁担是扁的，板凳是板的。扁担不是板凳，板凳不是扁担。别把扁担说成板凳，别把板凳说成扁担。'
            },
            31: {
                'content': '大姐编辫，两个人编。二姐编那半边，三姐编这半边；三姐编这半边，二姐编那半边。'
            },
            32: {
                'content': '小雨点，沙沙沙，落在田野里，苗儿乐得向上拔。小雨点，沙沙沙，落在鱼池里，鱼儿乐得摇尾巴。'
            },
            33: {
                'content': '容容和润润，榕树下玩藏身，一个找，一个藏，又是喊，又是嚷。润润找不到容容，容容看不见润润。这榕树能容多少人？谁也说不准。'
            },
            34: {
                'content': '葫芦秧开葫芦花，葫芦花结葫芦瓜。葫芦秧是葫芦家，葫芦家有葫芦娃。'
            },
            35: {
                'content': '卜家卜小五，种了五亩谷。跑来一群鼠，在地里吃谷。小五忙割谷，顾不得捉鼠。小五想捉鼠，就顾不得割谷。忙坏了卜小五，没捉住老鼠，还糟蹋了很多谷。'
            },
            36: {
                'content': '小郭画了朵红花，小葛画了朵黄花，小郭想拿他的红花换小葛的黄花，小葛把他的黄花换了小郭的红花。'
            },
            37: {
                'content': '尖尖山上放紫藤，紫藤四面挂铜铃。风吹藤动铜铃响，风住藤定定铜铃。'
            },
            38: {
                'content': '白家白木材，蔡家白白菜。白家白木材换蔡家白白菜，蔡家白白菜换白家白木材。白家有白木材又有白白菜，蔡家有白白菜又有白木材。'
            },
            39: {
                'content': '金瓜瓜，银瓜瓜，瓜棚里结瓜瓜。瓜瓜熟，落下来，打着坐着的小娃娃。小娃娃瞪瓜瓜，要打瓜瓜打不着，哭着叫妈妈，妈妈抱娃娃，手指大瓜瓜，瓜瓜笑娃娃。'
            },
            40: {
                'content': '苏州玄妙观，东西两判官，东判官姓潘，西判官姓管，管判官要管潘判官，潘判官要管管判官，闹得谁也不服管。'
            },
            41: {
                'content': '藤绳挂风灯，风更猛，风更增，灯碰藤绳藤碰灯'
            },
            42: {
                'content': '房胡子，黄胡子，新年到了写福字；不知道房胡子的福字写得好？还是黄胡子的福字写得好？'
            },
            43: {
                'content': '庙外头一只白白猫，庙里头一只黑黑猫，黑黑猫背白白猫，白白猫背黑黑猫。'
            },
            44: {
                'content': '哥挎瓜筐过宽沟，赶快过沟看怪狗，光看怪狗瓜筐扣，瓜滚筐空哥怪狗。'
            },
            45: {
                'content': '薄板和短板，互相来比板。薄板薄，短板短，薄板要比短板薄，短板要比薄板短，薄板加一寸，薄板还是板薄，短板加一尺，短板还是板短。'
            },
            46: {
                'content': '有个懒汉本姓阮，提个篮子卖鸡卵，“卖卵”“卖卵”使劲喊，谁都不来买鸡卵，不是鸡卵品种乱，而是鸡卵皮太软。卖不出鸡卵难买饭，回家吃饭路又远，胡乱烧把烂草取取暖，再吃掉篮子里几个软鸡卵。'
            },
            47: {
                'content': '拉大锯，扯大锯，锯木头，盖房子，姥姥家，娶娘子，搭大棚，唱大戏，接姑娘，请女婿，小外甥，你也去。'
            },
            48: {
                'content': '南南有个篮，篮篮装着盘盘，盘盘放着碗碗，碗碗盛着饭饭。南南翻了篮篮，篮篮扣了盘盘，盘盘打了碗碗，碗碗撒了饭饭。'
            },
            49: {
                'content': '山前住的颜圆眼，山后住的颜眼圆，二人山前来比眼，也不知道颜圆眼比颜眼圆的圆眼，也不知道颜眼圆比颜圆眼的眼圆。'
            },
            50: {
                'content': '对河过来一只船这边漂去一张床行到河中互相撞不知床撞船还是船撞床'
            }
        }
        num = random.randint(0, 50)
        res_str = data[num]['content']
        return res_str

    except Exception as e:
        raise InternalError(e, 'ybc_funny')


_jizhuanwan_data = {
    0: {
        'answer': '答案：从左向右写',
        'content': '问题：作家的最好写作方式是什么？'
    },
    1: {
        'answer': '答案：站在与倾斜方向相对的地方看.',
        'content': '问题：有一天我去意大利参观著名的比萨斜塔时，却看到此塔一点也不倾斜，笔直而立。当时真怀疑自己是否眼花了，四周看不到修复的痕迹，也不是看到赝品。那么?究竟该如何说明这个事实呢?'
    },
    2: {
        'answer': '答案：薪水',
        'content': '问题：什么水不能喝？'
    },
    3: {
        'answer': '答案：打湿',
        'content': '问题：中国古贤人曾将兰色外衣，浸泡于黄河中，结果产生何种现象？'
    },
    4: {
        'answer': '答案：熊猫，你看它的黑眼圈',
        'content': '问题：什么动物天天熬夜？'
    },
    5: {
        'answer': '答案：人造卫星',
        'content': '问题：什么贵重的东西最容易不翼而飞？'
    },
    6: {
        'answer': '答案：沉默',
        'content': '问题：什么东西你只要叫一声它的名字它就会破坏？'
    },
    7: {
        'answer': '答案：外国人用国语与他交谈',
        'content': '问题：刚念幼儿园的皮皮才学英文一个月却能毫无困难地和外国人交谈，为什么？'
    },
    8: {
        'answer': '答案：因为大说已逝世',
        'content': '问题：为什么只看过“小说”，没看过“大说”？'
    },
    9: {
        'answer': '答案：蜂房',
        'content': '问题：什么样的房子不能住人？？'
    },
    10: {
        'answer': '答案：搞笑点名',
        'content': '问题：大二的时候，上法律课，我们法律老师有个癖好，喜欢提问，提问之前必高声重复一遍问题。有一次正在上《民法通则》，突然老师又提高声音开始提问，所有同学都恐惧地盯着老师，惟恐被喊到，因为老师以提问来代替点名，所以是看着点名册提问的，所以大家都不必低下头。“1班25号１老师点道。一片沉默（张三正在发呆）……“25号--张三！来了没有？”老师重复道，刷！整个教室的人都看着张三。“没来１张三大叫。全班人都愣了！'
    },
    11: {
        'answer': '答案：他可以把他爸爸的鼻子拿下来玩',
        'content': '问题：麦可杰克森的儿子是幸福的，为什么？'
    },
    12: {
        'answer': '答案：过目不忘（过木不汪）',
        'content': '问题：狗过了独木桥就不叫了（打一成语）'
    },
    13: {
        'answer': '答案：指针已经转过一圈了',
        'content': '问题：胖姐阿英站上人体秤时，为何指针却只指着5？'
    },
    14: {
        'answer': '答案：秘书',
        'content': '问题：书店买不到的书是什么书？'
    },
    15: {
        'answer': '答案：三分钟',
        'content': '问题：三个孩子吃三个饼要用3分钟，九十个孩子九十个饼要用多少时间?'
    },
    16: {
        'answer': '答案：因为年年都被炒鱿鱼',
        'content': '问题：年年有余，为什么钱还是存不起来？'
    },
    17: {
        'answer': '答案：前公（功）尽弃',
        'content': '问题：在一次考试中，两个学生交了一模一样的考卷，但老师认为他们肯定没有做弊，这是为什么？'
    },
    18: {
        'answer': '答案：苏武。原因：苏武牧羊北海边（被海扁）',
        'content': '问题：哪位历史人物最欠扁？'
    },
    19: {
        'answer': '答案：火葬',
        'content': '问题：人在什么情况下会七窍生烟？'
    },
    20: {
        'answer': '答案：扔最重的那一个.',
        'content': '问题：有一天，一个植物专家，一个原子弹专家，一个动物专家在一个热气球上。此时，热气球直线下降，必须扔掉一个科学家，请问扔哪一个？'
    },
    21: {
        'answer': '答案：药店',
        'content': '问题：一个自讨苦吃的地方在哪里？'
    },
    22: {
        'answer': '答案：明',
        'content': '问题：一阴一阳，一短一长，一昼一夜，合为一双。打一字。'
    },
    23: {
        'answer': '答案：上嘴唇和下嘴唇',
        'content': '问题：什么东西说“父亲”是不会相碰，叫“爸爸”时却会碰到两次？'
    },
    24: {
        'answer': '答案：瘦子',
        'content': '问题：哪些人觉得老天对自己不公平?'
    },
    25: {
        'answer': '答案：5个角',
        'content': '问题：一张方桌据掉一个角，还有几个角？'
    },
    26: {
        'answer': '答案：他自己的脚',
        'content': '问题：猜猜看：今年圣诞夜，圣诞老人第一件放进袜子里的是什么东西？'
    },
    27: {
        'answer': '答案：天方夜谭',
        'content': '问题：阿里巴巴和四十大盗的故事是东方夜谭还是西方夜谭?'
    },
    28: {
        'answer': '答案：算错了的时候',
        'content': '问题：在什么时候1+2不等于3？'
    },
    29: {
        'answer': '答案：划拳喝酒',
        'content': '问题：哪种比赛，赢的得不到奖品，输的却有奖品?'
    },
    30: {
        'answer': '答案：把门推开',
        'content': '问题：一个人被关在密闭的房间里，只有一扇门，但无法拉开，他该如何出来？'
    },
    31: {
        'answer': '答案：因为伍佰去唱歌了',
        'content': '问题：800壮士为什么只剩下300人了?'
    },
    32: {
        'answer': '答案：呼吸保持顺畅.',
        'content': '问题：最简单的长寿之道是什么？'
    },
    33: {
        'answer': '答案：眼皮',
        'content': '问题：比眼大的东西是什么?'
    },
    34: {
        'answer': '答案：鸡蛋',
        'content': '问题：什么东西从屁股里排出后还可以当食物?'
    },
    35: {
        'answer': '答案：瞎子',
        'content': '问题：什么人生病从来不看医生？'
    },
    36: {
        'answer': '答案：打火机怎么剔牙齿',
        'content': '问题：连长用餐完毕向一旁的朱排长借火柴，朱排长殷勤的掏出“都彭”打火机，却被连长白了他一眼，为什么？'
    },
    37: {
        'answer': '答案：小白兔（TWO）',
        'content': '问题：小白加小白等于什么？'
    },
    38: {
        'answer': '答案：榨成橙汁分',
        'content': '问题：五个人分六个橙子怎么分才算合理？'
    },
    39: {
        'answer': '答案：算错时',
        'content': '问题：什么时候4-3=5？'
    },
    40: {
        'answer': '答案：亲戚',
        'content': '问题：你姨夫的姐姐的堂弟的表哥的爸爸是你的什么人？'
    },
    41: {
        'answer': '答案：梦',
        'content': '问题：闭着眼睛也看得见的是什么？'
    },
    42: {
        'answer': '答案：这里的“阿明”是条狗的名字',
        'content': '问题：在地上有100元钱和一块肉骨头，可是阿明却拣起了肉骨头而没有捡钱，为什么？'
    },
    43: {
        'answer': '答案：鸵鸟不会飞',
        'content': '问题：气候突然转冷，一只鸵鸟决定南迁，请问它头向南，尾朝北，而爪子该朝向哪一方呢？'
    },
    44: {
        'answer': '答案：射击',
        'content': '问题：做什么事，一只眼开一只眼闭会比较好？'
    },
    45: {
        'answer': '答案：半条虫子',
        'content': '问题：吃苹果时，咬了一口发现有一条虫子，觉得特别恶心；看到两条虫子，觉得更恶心；请问：看到几条虫子让人最恶心？'
    },
    46: {
        'answer': '答案：四个蛋放到四个角上.',
        'content': '问题：明尼波里市的某个蛋商，在空房间的地板上放置四个蛋。然后用一个铁制的大滚筒，推压整个房间;蛋却一个都没破。这是为什么?'
    },
    47: {
        'answer': '答案：沉默',
        'content': '问题：你只要叫它的名字就会把它破坏，它是什么？'
    },
    48: {
        'answer': '答案：小白是狗呀',
        'content': '问题：为什么小白看见１００元和肉骨头他选肉骨头？'
    },
    49: {
        'answer': '答案：这道题',
        'content': '问题：世界上最难的一道题是哪道题？'
    },
    50: {
        'answer': '答案：把眼睛闭上就可以做到了',
        'content': '问题：李哲看起来平平常常，并无什么特别之处，但他却可以连续数小时不眨眼睛，他是怎么做到的呢？'
    }
}


def jizhuanwan_content():
    """
    :return: 随机返回一个脑筋急转弯的问题
    """
    try:
        num = random.randint(0, len(_jizhuanwan_data) - 1)
        res_str = _jizhuanwan_data[num]['content']
        return res_str

    except Exception as e:
        raise InternalError(e, 'ybc_funny')


def jizhuanwan_answer(content):
    """
    :return: 根据输入的content查找脑筋急转弯的答案
    """
    if not isinstance(content, str):
        raise ParameterTypeError(sys._getframe().f_code.co_name, "'content'")
    try:
        for current in _jizhuanwan_data.values():
            if current["content"] == content:
                return current["answer"]
        print("未找到对应答案")
        return -1
    except Exception as e:
        raise InternalError(e, 'ybc_funny')


_xiehouyu_data = {
    0: {
        'answer': '答案：两面怕；两头怕',
        'content': '问题：麻秆打狼'
    },
    1: {
        'answer': '答案：机会难得；难得的机会',
        'content': '问题：老虎打瞌睡'
    },
    2: {
        'answer': '答案：又尖又滑',
        'content': '问题：(牛)角抹油'
    },
    3: {
        'answer': '答案：砸啦',
        'content': '问题：鸡蛋筐里放秤碗'
    },
    4: {
        'answer': '答案：抹不掉；不能容人',
        'content': '问题：白纸上画黑道'
    },
    5: {
        'answer': '答案：少来',
        'content': '问题：和尚串门'
    },
    6: {
        'answer': '答案：一捏两瓣',
        'content': '问题：六月的面杏'
    },
    7: {
        'answer': '答案：柔中有刚；软中有硬',
        'content': '问题：棉花裹秤砣'
    },
    8: {
        'answer': '答案：大小是个头',
        'content': '问题：电线杆上插土豆'
    },
    9: {
        'answer': '答案：抬不起头来',
        'content': '问题：吃了有毒食物的老母鸡'
    },
    10: {
        'answer': '答案：两头挨刀(比喻两方面受责难)',
        'content': '问题：红蓝铅笔'
    },
    11: {
        'answer': '答案：收买人心',
        'content': '问题：黄鼠狼为鸡立碑'
    },
    12: {
        'answer': '答案：道道多',
        'content': '问题：龙王爷的帽子'
    },
    13: {
        'answer': '答案：冷静',
        'content': '问题：北冰洋的夜晚'
    },
    14: {
        'answer': '答案：四世同堂',
        'content': '问题：百岁老人做大寿'
    },
    15: {
        'answer': '答案：爱叫；学舌；能说不能干；',
        'content': '问题：八哥的嘴'
    },
    16: {
        'answer': '答案：不敢（擀）',
        'content': '问题：鏊子（aozi烙饼的炊具。铁制圆形平底）里摊饼'
    },
    17: {
        'answer': '答案：反常',
        'content': '问题：阿婆留胡子'
    },
    18: {
        'answer': '答案：哪能轮到你',
        'content': '问题：三个人讲两句话'
    },
    19: {
        'answer': '答案：费力不讨好',
        'content': '问题：背着石磨上山'
    },
    20: {
        'answer': '答案：极致',
        'content': '问题：鸡蛋里挑骨头'
    },
    21: {
        'answer': '答案：装羊；装样；装洋；出羊相；出洋相',
        'content': '问题：狼头上长角'
    },
    22: {
        'answer': '答案：差对差；差配差',
        'content': '问题：坏笤帚对烂畚箕'
    },
    23: {
        'answer': '答案：命重',
        'content': '问题：八字千斤'
    },
    24: {
        'answer': '答案：伤不了和气',
        'content': '问题：牙齿和舌头打架'
    },
    25: {
        'answer': '答案：正是时候',
        'content': '问题：初一早上放鞭炮'
    },
    26: {
        'answer': '答案：心底纯正',
        'content': '问题：刚出炉的铁'
    },
    27: {
        'answer': '答案：心里恨',
        'content': '问题：哑巴咬牙'
    },
    28: {
        'answer': '答案：不是正经材料；难撑难顶',
        'content': '问题：葵花秆当柱子'
    },
    29: {
        'answer': '答案：坏透了',
        'content': '问题：发臭的酸奶'
    },
    30: {
        'answer': '答案：一步一个脚印',
        'content': '问题：泥地上跑马'
    },
    31: {
        'answer': '答案：非同小可',
        'content': '问题：如来佛打喷嚏'
    },
    32: {
        'answer': '答案：一起手就到',
        'content': '问题：从灶门坎搬上锅台'
    },
    33: {
        'answer': '答案：吃了木得玩的，玩了木得吃的；吃了冇得玩的，玩了冇得吃的；吃了没有玩的，玩了没有吃的',
        'content': '问题：三个钱买个糖人'
    },
    34: {
        'answer': '答案：怪物',
        'content': '问题：驴子下只象'
    },
    35: {
        'answer': '答案：自图胆大不顾羞耻',
        'content': '问题：精尻子骑老虎'
    },
    36: {
        'answer': '答案：滑不到哪里去',
        'content': '问题：坛子里装泥鳅'
    },
    37: {
        'answer': '答案：越练（炼）越结实',
        'content': '问题：孙悟空进了八卦炉'
    },
    38: {
        'answer': '答案：找不到说理的地方',
        'content': '问题：做梦挨驴踢'
    },
    39: {
        'answer': '答案：不可多得；一个个来',
        'content': '问题：筷子夹豌豆'
    },
    40: {
        'answer': '答案：半边阴',
        'content': '问题：初七八的月亮'
    },
    41: {
        'answer': '答案：多此一举',
        'content': '问题：白天开灯'
    },
    42: {
        'answer': '答案：合在一起干',
        'content': '问题：黄沙搀水泥'
    },
    43: {
        'answer': '答案：没有好货',
        'content': '问题：老狼做生意'
    },
    44: {
        'answer': '答案：倒挨一脚',
        'content': '问题：拍马屁拍到蹄子上'
    },
    45: {
        'answer': '答案：刻薄',
        'content': '问题：牛毛上解锯'
    },
    46: {
        'answer': '答案：粗中有细',
        'content': '问题：张飞施计划'
    },
    47: {
        'answer': '答案：自取灭亡',
        'content': '问题：飞蛾扑火'
    },
    48: {
        'answer': '答案：窟窿套窟窿',
        'content': '问题：惜债买藉吃'
    },
    49: {
        'answer': '答案：这把骨头不知扔在哪儿',
        'content': '问题：骑着毛驴吃烧鸭烧鸡'
    },
    50: {
        'answer': '答案：没着落',
        'content': '问题：迷途的信鸽'
    }
}


def xiehouyu_content():
    """
    :return: 随机返回一个歇后语的问题
    """
    try:
        num = random.randint(0, len(_xiehouyu_data) - 1)
        res_str = _xiehouyu_data[num]['content']
        return res_str

    except Exception as e:
        raise InternalError(e, 'ybc_funny')


def xiehouyu_answer(content):
    """
    :return: 根据输入的content查找歇后语的答案
    """
    if not isinstance(content, str):
        raise ParameterTypeError(sys._getframe().f_code.co_name, "'content'")
    try:
        for current in _xiehouyu_data.values():
            if current["content"] == content:
                return current["answer"]
        print("未找到对应答案")
        return -1
    except Exception as e:
        raise InternalError(e, 'ybc_funny')


_miyu_data = {
    0: {
        'answer': '答案：手指',
        'content': '问题：五个兄弟，住在一起，名字不同，高矮不齐。（打身体一个部位）'
    },
    1: {
        'answer': '答案：冰箱',
        'content': '问题：屋子方方，有门没窗，屋外热烘，屋里冰霜。（打一个家电）'
    },
    2: {
        'answer': '答案：荷花',
        'content': '问题：一个小姑娘，生在水中央，身穿粉红衫，坐在绿船上。（打一种花)'
    },
    3: {
        'answer': '答案：桌子',
        'content': '问题：有面没有口，有脚没有手，虽有四只脚，自己不会走。（打一件家具）'
    },
    4: {
        'answer': '答案：锅',
        'content': '问题：上不怕水，下不怕火;家家厨房，都有一个 (打一生活用品)。'
    },
    5: {
        'answer': '答案：不倒翁',
        'content': '问题：一个老头，不跑不走;请他睡觉，他就摇头 (打一物)。'
    },
    6: {
        'answer': '答案：桥',
        'content': '问题：驼背公公，力大无穷;爱驮什么车水马龙(打一物)。'
    },
    7: {
        'answer': '答案：公鸡',
        'content': '问题：头戴红帽子，身披五彩衣，从来不唱戏，喜欢吊嗓子(打一动物)。'
    },
    8: {
        'answer': '答案：龟',
        'content': '问题：头小颈长四脚短，硬壳壳里把身安，别看胆小又怕事，要论寿命大无边。(打一动物)。'
    },
    9: {
        'answer': '答案：袋鼠',
        'content': '问题：一物长来真奇怪，肚皮下面长口袋，孩子袋里吃和睡，跑得不快跳得快。(打一动物)。'
    },
    10: {
        'answer': '答案：大象',
        'content': '问题：耳朵像蒲扇，身子像小山，鼻子长又长，帮人把活干。 (打一动物)。'
    },
    11: {
        'answer': '答案：螃蟹',
        'content': '问题：八只脚，抬面鼓，两把剪刀鼓前舞，生来横行又霸道，嘴里常把泡沫吐。(打一动物)。'
    },
    12: {
        'answer': '答案：骆驼',
        'content': '问题：头像绵羊颈似鹅，不是牛马不是骡，戈壁滩上万里行，能耐渴来能忍饿。(一动物)。'
    },
    13: {
        'answer': '答案：鸭子',
        'content': '问题：嘴像小铲子，脚像小扇子，走路左右摆，水上划船子。(一动物)。'
    },
    14: {
        'answer': '答案：蝌蚪',
        'content': '问题：身子像个小逗点，摇着一根小尾巴，从小就会吃孑孓，长大吃虫叫哇哇。(一动物)。'
    },
    15: {
        'answer': '答案：蜻蜓',
        'content': '问题：小飞机，纱翅膀，飞来飞去灭虫忙，低飞雨，高飞睛，气象预报它内行。'
    },
    16: {
        'answer': '答案：故弄玄虚',
        'content': '问题：老巷幻影（打一成语）'
    },
    17: {
        'answer': '答案：冰箱',
        'content': '问题：屋子方方，有门有窗，屋外热乎，屋里冰凉。（打一家用电器）'
    },
    18: {
        'answer': '答案：手指',
        'content': '问题：五个兄弟，住在一起，名字不同，高矮不齐。（打一人体部位）'
    },
    19: {
        'answer': '答案：不倒翁',
        'content': '问题：一位爷爷精神好，身小体轻劲不小，左推右推推不倒。（打一玩具）'
    },
    20: {
        'answer': '答案：日历',
        'content': '问题：一本书，天天看，看了一页撕一页。（打一物品）'
    },
    21: {
        'answer': '答案：鼓',
        'content': '问题：一个大肚皮，生来怪脾气，不打不做声，越打越欢喜。（打一乐器）'
    },
    22: {
        'answer': '答案：蒜',
        'content': '问题：兄弟七八个，围着柱子坐。要是一分家，衣服全扯破。（打一食物）'
    },
    23: {
        'answer': '答案：玉米',
        'content': '问题：奇怪奇怪真奇怪，头顶长出胡子来。解开衣服看一看，颗颗珍珠露出来。（打一植物）'
    },
    24: {
        'answer': '答案：雪',
        'content': '问题：说像糖，它不甜。说是盐，又不咸。冬天有时一大片，夏天谁都看不见。（打一自然现象）'
    },
    25: {
        'answer': '答案：剪刀',
        'content': '问题：两脚弯弯细又长，一张嘴巴明晃晃。不吃米面不吃菜，专吃布匹和纸张。（打一生活用品）'
    },
    26: {
        'answer': '答案：照相机',
        'content': '问题：有个画家真奇怪，画画不用笔和彩。朝它面前站一站，咔嚓一下画下来。（打一生活用品）'
    },
    27: {
        'answer': '答案：钟表',
        'content': '问题：哥哥要比弟弟矮，两人赛跑大家看。弟弟跑了十二圈，哥哥刚刚才一圈。（打一生活用品）'
    },
    28: {
        'answer': '答案：镜子',
        'content': '问题：你哭他也哭，你笑他也笑。脸上脏不脏，看它就知道。（打一生活用品）'
    },
    29: {
        'answer': '答案：耳朵',
        'content': '问题：一个住这边，一个住那边。说话能听见，到老不见面。（打一人体部位）'
    },
    30: {
        'answer': '答案：啄木鸟',
        'content': '问题：有个医生医术高，尖嘴好像手术刀。敲开树皮把病瞧，叼出蛀虫一条条。（打一动物）'
    },
    31: {
        'answer': '答案：军',
        'content': '问题：挥手离去。（打一字）'
    },
    32: {
        'answer': '答案：口',
        'content': '问题：家没有国有，弟没有兄有；左没有右有，前没有后有。（打一字）'
    },
    33: {
        'answer': '答案：彩虹',
        'content': '问题：弯弯一座彩色桥，高高挂在半山腰，七色鲜艳真正好，一会儿工夫不见了。（打一自然现象）'
    },
    34: {
        'answer': '答案：太阳',
        'content': '明又明，亮又亮，一团火球挂天上。冬天呆的时间短，夏天呆的时间长。（打一自然现象）'
    },
    35: {
        'answer': '答案：雪',
        'content': '说象糖，它不甜，说象盐，又不咸。冬天有时一片，夏天谁都不见。（打一自然现象）'
    },
    36: {
        'answer': '答案：梅花鹿',
        'content': '15、头上长树杈，身上有白花，四腿跑得快，生长在山野。（打一动物）'
    },
    37: {
        'answer': '答案：蜜蜂',
        'content': '百花丛中嗡嗡唱，劳动歌声韵味长，采得花来酿花蜜，蜜儿香甜万家尝。（打一昆虫）'
    },
    38: {
        'answer': '答案：牙刷',
        'content': '一根小棍五寸长，一头有毛一头光， 出来就爱讲卫生，天天嘴里走两趟。（打一日用品）'
    },
    39: {
        'answer': '答案：筷子',
        'content': '兄弟两个一般高，一天三餐不长膘。（打一日用品）'
    },
    40: {
        'answer': '答案：耳朵',
        'content': '一个住在这边，一个住在那边，说话都能听见，到老也不见面。（打一人体器官）'
    },
    41: {
        'answer': '答案：猪',
        'content': '全身都是宝，爱吃百样草，吃饱就睡觉，走路哼哼叫。（打一家畜）'
    },
    42: {
        'answer': '答案：熊猫',
        'content': '身披黑白棉袄，模样像只狗熊，走路摇摇摆摆，爱吃竹子嫩叶。（打一动物）'
    },
    43: {
        'answer': '答案：镜子',
        'content': '你哭他也哭，你笑他也笑，脸上脏不脏，看它就知道。（打一日用品）'
    },
    44: {
        'answer': '答案：西瓜',
        'content': '身穿绿衣裳，肚里水汪汪，生的子儿多，个个黑脸膛。（打一水果）'
    },
    45: {
        'answer': '答案：大象',
        'content': '耳朵像蒲扇，身子像小山，鼻子长又长，帮人把活干。（打一动物）'
    },
    46: {
        'answer': '答案：刺猬',
        'content': '小货郎，不挑担，背着针，满处窜。（打一动物）'
    },
    47: {
        'answer': '答案：鸭子',
        'content': '嘴像小铲子，脚像小扇子，走路左右摆，水上划船子。（打一动物）'
    }
}


def miyu_content():
    """
    :return: 随机返回一个谜语的问题
    """
    try:
        num = random.randint(0, len(_miyu_data) - 1)
        res_str = _miyu_data[num]['content']
        return res_str

    except Exception as e:
        raise InternalError(e, 'ybc_funny')


def miyu_answer(content):
    """
    :return: 根据输入的content查找谜语的答案
    """
    if not isinstance(content, str):
        raise ParameterTypeError(sys._getframe().f_code.co_name, "'content'")
    try:
        for current in _miyu_data.values():
            if current["content"] == content:
                return current["answer"]
        print("未找到对应答案")
        return -1
    except Exception as e:
        raise InternalError(e, 'ybc_funny')


def main():
    print(miyu_answer(miyu_content()))
    print(jizhuanwan_answer(jizhuanwan_content()))
    print(xiehouyu_answer(xiehouyu_content()))
    print(raokouling())
    print(xiaohua())


if __name__ == '__main__':
    main()



from distutils.core import setup

setup(
    name='ybc_funny',
    version='1.1.0',
    description='Get The Funny Text',
    long_description='Get The Funny Text',
    author='zhangyun',
    author_email='zhangyun@fenbi.com',
    keywords=['pip3', 'python3', 'python', 'brain', 'funny', 'joke'],
    url='http://pip.zhenguanyu.com/',
    packages=['ybc_funny'],
    package_data={'ybc_funny': ['*.py']},
    license='MIT',
    install_requires=[
        'ybc_exception'
    ]
)
